==> horde_sdk-0.5.2.tar.gz: horde_sdk-0.5.2/README.md <==

[![Tests](https://github.com/Haidra-Org/horde-sdk/actions/workflows/maintests.yml/badge.svg)](https://github.com/Haidra-Org/horde-sdk/actions/workflows/maintests.yml)
[![Documentation Status](https://readthedocs.org/projects/horde-sdk/badge/?version=latest)](https://horde-sdk.readthedocs.io/en/latest/?badge=latest)
[![Unstable Tests](https://github.com/Haidra-Org/horde-sdk/actions/workflows/prtests.yml/badge.svg)](https://github.com/Haidra-Org/horde-sdk/actions/workflows/prtests.yml)
# horde_sdk

## Note
horde_sdk is in **alpha**. Everything is subject to change. Please feel free to report bugs or make suggestions on our [github issue page](https://https//github.com/Haidra-Org/horde-sdk)

## About
This library simplifies interfacing with any API created by [Haidra](https://github.com/Haidra-Org) - the community organization
behind the free projects such as AI-Horde ([homepage](https://aihorde.net/), [github](https://github.com/db0/AI-Horde)).
The goal is to minimize the amount of time it takes to develop applications in python that use our free, volunteer driven, services which include:

- Stable Diffusion Image Generation (driven by [ComfyUI](https://github.com/comfyanonymous/ComfyUI))
- Image captioning
- Image rating (currently ratings are for [diffusiondb](https://poloclub.github.io/diffusiondb/), others coming in the future)
- Text Generation using LLMs (driven by [KoboldAI](https://github.com/KoboldAI/KoboldAI-Client))

From anything to requesting your own images, or rolling your own [worker](https://github.com/Haidra-Org/AI-Horde-Worker) software, this package may suit your needs.

## Documentation
See the complete documentation at https://horde-sdk.readthedocs.io/en/latest/.

==> horde_sdk-0.10.0.tar.gz: horde_sdk-0.10.0/README.md <==

[![Tests](https://github.com/Haidra-Org/horde-sdk/actions/workflows/maintests.yml/badge.svg)](https://github.com/Haidra-Org/horde-sdk/actions/workflows/maintests.yml)
[![Documentation Status](https://readthedocs.org/projects/horde-sdk/badge/?version=latest)](https://horde-sdk.readthedocs.io/en/latest/?badge=latest)
[![Unstable Tests](https://github.com/Haidra-Org/horde-sdk/actions/workflows/prtests.yml/badge.svg)](https://github.com/Haidra-Org/horde-sdk/actions/workflows/prtests.yml)
# horde_sdk

## Note
horde_sdk is in **beta**. Everything is subject to change. Please feel free to report bugs or make suggestions on our [github issue page](https://https//github.com/Haidra-Org/horde-sdk)

## About
This library simplifies interfacing with any API created by [Haidra](https://github.com/Haidra-Org) - the community organization
behind the free projects such as AI-Horde ([homepage](https://aihorde.net/), [github](https://github.com/db0/AI-Horde)).
The goal is to minimize the amount of time it takes to develop applications in python that use our free, volunteer driven, services which include:

- Stable Diffusion Image Generation (driven by [ComfyUI](https://github.com/comfyanonymous/ComfyUI))
- Image captioning
- Image rating (currently ratings are for [diffusiondb](https://poloclub.github.io/diffusiondb/), others coming in the future)
- Text Generation using LLMs (driven by [KoboldAI](https://github.com/KoboldAI/KoboldAI-Client))

From anything to requesting your own images, or rolling your own [worker](https://github.com/Haidra-Org/AI-Horde-Worker) software, this package may suit your needs.

## Documentation
See the complete documentation at https://horde-sdk.readthedocs.io/en/latest/.
